==> gerbera-1.9.0.tar.gz: gerbera-1.9.0/src/url_request_handler.h <==
/*MT*
    
    MediaTomb - http://www.mediatomb.cc/
    
    url_request_handler.h - this file is part of MediaTomb.
    
    Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                       Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
    
    Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                            Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                            Leonhard Wimmer <leo@mediatomb.cc>
    
    MediaTomb is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2
    as published by the Free Software Foundation.
    
    MediaTomb is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    version 2 along with MediaTomb; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
    
    $Id$
*/

/// \file url_request_handler.h
/// \brief Definition of the URLRequestHandler class.
#ifndef __URL_REQUEST_HANDLER_H__
#define __URL_REQUEST_HANDLER_H__

#include "common.h"
#include "request_handler.h"

class URLRequestHandler : public RequestHandler {
public:
    explicit URLRequestHandler(std::shared_ptr<ContentManager> content);

    void getInfo(const char* filename, UpnpFileInfo* info) override;
    std::unique_ptr<IOHandler> open(const char* filename, enum UpnpOpenFileMode mode) override;
};

#endif // __URL_REQUEST_HANDLER_H__

==> gerbera-1.11.0.tar.gz: gerbera-1.11.0/src/url_request_handler.h <==
/*MT*

    MediaTomb - http://www.mediatomb.cc/

    url_request_handler.h - this file is part of MediaTomb.

    Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                       Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>

    Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                            Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                            Leonhard Wimmer <leo@mediatomb.cc>

    MediaTomb is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2
    as published by the Free Software Foundation.

    MediaTomb is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    version 2 along with MediaTomb; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

    $Id$
*/

/// \file url_request_handler.h
/// \brief Definition of the URLRequestHandler class.
#ifndef __URL_REQUEST_HANDLER_H__
#define __URL_REQUEST_HANDLER_H__

#include "common.h"
#include "request_handler.h"

class URLRequestHandler : public RequestHandler {
    using RequestHandler::RequestHandler;

public:
    void getInfo(const char* filename, UpnpFileInfo* info) override;
    std::unique_ptr<IOHandler> open(const char* filename, enum UpnpOpenFileMode mode) override;
};

#endif // __URL_REQUEST_HANDLER_H__
